@@ -9,22 +9,20 @@ class Client(object):
 
     Attributes:
         token(string): token used for query
-        url(string): BinaryAI api endpoint url, default is https://api.binaryai.tencent.com/v1/endpoint
+        url(string): BinaryAI api endpoint url
         timeout(int): seconds of timeout, default is 1000
     '''
 
     def __init__(
         self,
         token,
-        url="https://api.binaryai.tencent.com/v1/endpoint",
+        url,
         timeout=1000,
     ):
+        self.token = token
         self.url = url
-        self.headers = {
-            "Content-Type": "application/json",
-            "token": token
-        }
         self.session = None
+        self._verify(self.token, self.url)
         self.GMT_FORMAT = '%a, %d %b %Y %H:%M:%S GMT'
         self.timeout = timeout
 
@@ -36,6 +34,20 @@ class Client(object):
         }
         return data
 
+    def _verify(self, token, url):
+        try:
+            response = requests.get(url, headers={"Token": token})
+        except Exception as e:
+            raise BinaryAIException("SDK_ERROR", "Request failed with exception: {}".format(e))
+        else:
+            if response.status_code == 401:
+                raise BinaryAIException("SDK_ERROR", "UNAUTHENTICATED: Invalid token")
+            elif response.status_code == 200:
+                return
+            else:
+                raise BinaryAIException("SDK_ERROR", "Invalid response: [{}] {}".format(
+                    response.status_code, response.content))
+
     def execute(self, query, var):
         '''
         Send request to API server and get response
@@ -50,23 +62,27 @@ class Client(object):
         if not self.session:
             self.session = requests.Session()
         data = self._gen_gql_data(query, var)
+        headers = {
+            "Content-Type": "application/json",
+            "Token": self.token
+        }
         response = None
         try:
             response = self.session.post(self.url, data=json.dumps(
-                data), headers=self.headers, timeout=self.timeout)
+                data), headers=headers, timeout=self.timeout)
         except Exception as e:
-            raise BinaryAIException("SDK_ERROR", "Request failed with exception: {}".format(e), None, None)
+            raise BinaryAIException("SDK_ERROR", "Request failed with exception: {}".format(e))
 
         try:
             jdata = json.loads(response.content)
         except Exception:
-            raise BinaryAIException("SDK_ERROR", "Invalid response: {}".format(response.content), None, None)
+            raise BinaryAIException("SDK_ERROR", "Invalid response: {}".format(response.content))
 
         if "errors" in jdata.keys():
             errors = jdata["errors"][0]
             raise BinaryAIException(errors['extensions']['code'], errors['message'], jdata['data'], jdata)
 
         if "data" not in jdata.keys():
-            raise BinaryAIException("SDK_ERROR", "Invalid response: {}".format(response.content), None, None)
+            raise BinaryAIException("SDK_ERROR", "Invalid response: {}".format(response.content))
 
         return jdata["data"]
